
.. _classic_tests_acoustics_1d_heterogeneous:

Acoustics 1D Example 1
------------------------------------------

1D acoustics in a piecewise constant medium to illustrate reflection and
transmission at an interface.

Quick regression test version:  regression_tests.py

* Checks sum of p values and of u values for two frames.
